using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using ZedGraph;

namespace StatisticalAnalyzer
{
	/// <summary>
	/// Summary description for GraphForEachRound.
	/// </summary>
	public class GraphForEachRound : System.Windows.Forms.Form
	{
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private GraphPane myPane;
		private GraphData myGD;
        Color[] LineColor = 
        {Color.Red, Color.Blue, Color.YellowGreen, Color.Orange, Color.Green};	
		SymbolType[] Symbol = {SymbolType.Circle, SymbolType.Diamond, SymbolType.Star, 
								  SymbolType.Triangle, SymbolType.Square};
		
		public GraphForEachRound()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
			myGD = new GraphData();
		}

		public GraphForEachRound(GraphData p_GD)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
			try
			{
				myGD = p_GD;
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in constructor of GraphForEachRounds():"+e.Message);
			}

        }

		private double getValue(string p_key)
		{
			double D = 0;
			try
			{
				IDictionaryEnumerator ide = myGD.XParam_Interval.GetEnumerator();
				while(ide.MoveNext())
				{
					if(ide.Key.ToString().Equals(p_key))
					{
						D = double.Parse(ide.Value.ToString());  
						break;
					}
				}
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getValue(): "+e.Message);
			}
			return D;
		}
		private double[] getXs()
		{
			int length = myGD.XParam_Interval.Count;
			double[] doubleXParam = new double[length];
			try
			{
				for(int i = 1; i<=length; i++)
				{
					doubleXParam[i-1] = getValue(i.ToString());
				}
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getX(): "+e.Message);
			}
			return doubleXParam;
		}

		private double[] getYs()
		{
			double[] doubleYValues = new double[myGD.DataForEachRound.Count];
			try
			{

               
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getY(): "+e.Message);
			}
			return doubleYValues;
		}

		private double[] convertToDoubleArray(ArrayList p_al)
		{
			double[] doubleAL = new double[p_al.Count];
			try
			{
				for(int i =0; i< p_al.Count; i++)
				{
					doubleAL[i] = double.Parse(p_al[i].ToString());
				}
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in convertToDoubleArray(): "+e.Message);
			}
			return doubleAL;
		}
		private double[] getDoubleYValue(string p_round)
		{
			double[] doubleYValues = new double[myGD.XParam_Interval.Count];
			try
			{
				IDictionaryEnumerator ide = myGD.DataForEachRound.GetEnumerator();
				while(ide.MoveNext())
				{
					if(ide.Key.ToString().Equals(p_round))
					{
						ArrayList temp = (ArrayList) ide.Value;
						doubleYValues = convertToDoubleArray(temp);
						break;
					}
				}
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getDoubleYValue(): "+e.Message);
			}
			return doubleYValues;
		}
		private double[] getDoubleYs(double[] p_doubleYMean, double[] p_doubleYValue)
		{			
			try
			{
				for(int i= 0; i<p_doubleYMean.Length; i++)
				{
					p_doubleYMean[i] += p_doubleYValue[i];
				}
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getDoubleYMean(): "+e.Message);
			}
			return p_doubleYMean;
		}
		private void showDoubleYValue(double[] p_doubleYValue)
		{
			string inside = "";
			for(int i = 0; i<p_doubleYValue.Length; i++)
			{
				inside += p_doubleYValue[i].ToString()+" ";
			}
			MessageBox.Show(inside);
		}

		private double[] getAvgDoubleYs(double[] doubleYs)
		{
			double[] avgDoubleYs = new double[doubleYs.Length];
			try
			{
				double numOfRound = double.Parse(myGD.DataForEachRound.Count.ToString());
				for(int i =0; i<doubleYs.Length; i++)
				{
					avgDoubleYs[i] = (doubleYs[i]/numOfRound);
				}
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getAvgDoubleYs(): "+e.Message);
			}
			return avgDoubleYs;
		}
		private double[] getMeanY()
		{
			
			double[] doubleYs = new double[myGD.XParam_Interval.Count];
			double[] doubleYMean = new double[myGD.XParam_Interval.Count];
			try
			{
				for(int i =1; i<= myGD.DataForEachRound.Count; i++)
				{
					double[] doubleYValue = getDoubleYValue(i.ToString());
					//showDoubleYValue(doubleYValue);
					doubleYs = getDoubleYs(doubleYs, doubleYValue);
				}
				doubleYMean = getAvgDoubleYs(doubleYs);				
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getMeanY(): "+e.Message);
			}
			return doubleYMean;
		}

		private void showDoubleArray(double[] p_al)
		{
			string inside = "";
			for(int i =0; i<p_al.Length; i++)
			{
				inside += p_al[i].ToString()+" ";
			}
			MessageBox.Show(inside);
		}
		private void ShowGraph()
		{
			string title = myGD.x_parameter+" vs. "+myGD.y_parameter;	
			string xparam = getXParam(myGD.x_parameter);
			string yparam = getYParam(myGD.y_parameter);
			myPane = new GraphPane(new Rectangle(20,20, this.Width-50, this.Height-110), 
				title, xparam, yparam);

			double[] x = getXs();

			int numOfRound = myGD.DataForEachRound.Count;
			for(int i = 1; i<=numOfRound; i++)
			{			
				double[] y = getDoubleYValue(i.ToString());
				CurveItem myCurve1 = myPane.AddCurve("Round "+i.ToString()+" for "+myGD.y_parameter, 
					x, y, LineColor[i-1], Symbol[i-1]);
			}
			myPane.AxisChange();				
		}

		private string getXParam(string p_param)
		{
			string param = "";
			try
			{
				if(p_param.Equals("Speed"))
				{
					param = p_param+" (m/s)"; 
				}
				else if(p_param.Equals("Pause Time"))
				{
					param = p_param+" (sec)"; 
				}
				else
				{
					param = p_param;
				}
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getXParam(): "+e.Message);
			}
			return param;
		}

		private string getYParam(string p_param)
		{
			string param = "";
			try
			{
				if(p_param.Equals(COMMONCONSTANTS.AVE_LATENCY_FINDING_ROUTE) ||
					p_param.Equals(COMMONCONSTANTS.AVE_LATENCY_DELIVERYING_DP))
				{
					param = p_param+" (sec)"; 
				}
				else
				{
					param = p_param;
				}
			}
			catch(Exception e)
			{
				MessageBox.Show("Exception in getYParam(): "+e.Message);
			}
			return param;

		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			// 
			// GraphForEachRound
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(736, 493);
			this.Name = "GraphForEachRound";
			this.Text = "GraphForEachRound";
			this.Load += new System.EventHandler(this.GraphForEachRound_Load);
			this.Paint += new PaintEventHandler(GraphForEachRound_Paint);
		}
		#endregion

		private void GraphForEachRound_Load(object sender, System.EventArgs e)
		{
			ShowGraph();
		}

		private void GraphForEachRound_Paint(object sender, PaintEventArgs e)
		{
            myPane.Draw(e.Graphics);
		}
	}
}
